@@ -8,7 +8,6 @@ from .exceptions import InvalidDateParams
 from .tools import (
     get_file_link,
     check_file_exist,
-    write_file,
     upload_to_s3,
     delete_file,
 )
@@ -19,6 +18,8 @@ class BaseDataManager(object):
     serializer: Any = None
     default_limit: int = 150000
     query_limit: int = 1000
+    with_last_id: bool = True
+    last_id_field: str = 'id'
 
     def __init__(self, integration_id: int, date_from: str, date_to: str):
         self.integration_id = integration_id
@@ -51,23 +52,26 @@ class BaseDataManager(object):
     def serialize_data(self, data: Any, fields: list) -> Union[Generator, list, dict]:
         raise NotImplementedError('serialize_data must be implemented.')
 
-    def _generate_file(self, skip: int, s3_filename: str, fields: list) -> str:
+    def _generate_file(self, skip: int, s3_filename: str, fields: list) -> tuple:
         if check_file_exist(s3_filename):
             skip += self.default_limit
             return get_file_link(s3_filename)
         with open(s3_filename, 'w') as f:
             writer = csv.DictWriter(f, delimiter='\t', fieldnames=fields)
             writer.writeheader()
+            last_id = None
             while True:
-                qs = self.get_data()
+                qs = self.get_data(last_id=last_id)
                 if not qs:
                     break
+                if self.with_last_id:
+                    last_id = getattr(qs[-1], self.last_id_field)
                 data = self.serialize_data(qs, fields)
                 for row in data:
                     writer.writerow(row)
                 skip += self.query_limit
         s3_file_data = upload_to_s3(s3_filename)
-        return get_file_link(s3_file_data['s3_filename'])
+        return skip, get_file_link(s3_file_data['s3_filename'])
 
     def _generate_result(self, filename: str, fields: list) -> dict:
         skip = 0
@@ -75,7 +79,8 @@ class BaseDataManager(object):
         count = self.get_count()
         links = []
         if self.default_limit >= count:
-            links.append(self._generate_file(skip, f'{filename}.tsv', fields))
+            skip, link = self._generate_file(skip, f'{filename}.tsv', fields)
+            links.append(link)
             delete_file(f'{filename}.tsv')
         else:
             while skip <= count:
@@ -83,7 +88,8 @@ class BaseDataManager(object):
                     part += 1
                     part_filename = f'{filename}_{part}'
                     s3_filename = f"{part_filename}.tsv"
-                    links.append(self._generate_file(skip, f'{filename}.tsv', fields))
+                    skip, link = self._generate_file(skip, f'{filename}.tsv', fields)
+                    links.append(link)
                     delete_file(s3_filename)
         return {'links': links}
 
